<img src=https://github.com/khiopsML/khiops/blob/dev/packaging/common/images/khiops.png width=60 />

# Khiops
Khiops is an AutoML suite for supervised and unsupervised learning

## Installation
For the installation instructions [go to Khiops website][khiops-web].

## Documentation
See the documentation [at the Khiops website][khiops-web]

## Development
See the [developer's documentation wiki][wiki-dev].

## License
This software is distributed under the BSD 3-Clause-clear License, the text of which is available at
https://spdx.org/licenses/BSD-3-Clause-Clear.html or see the [LICENSE](./LICENSE) for more
details.

## Help Contact
khiops.team@orange.com


[khiops-web]: https://khiops.org
[wiki-dev]: https://github.com/KhiopsML/khiops/wiki
